@@ -714,12 +714,12 @@ impl Parser {
                     },
                     Token::Number(ref n) => match n.parse::<i64>() {
                         Ok(n) => {
-                            if let Some(Token::Minus) = self.peek_token() {
-                                self.prev_token();
-                                self.parse_timestamp_value()
-                            } else {
+//                            if let Some(Token::Minus) = self.peek_token() {
+//                                self.prev_token();
+//                                self.parse_timestamp_value()
+//                            } else {
                                 Ok(Value::Long(n))
-                            }
+//                            }
                         }
                         Err(e) => parser_err!(format!("Could not parse '{}' as i64: {}", n, e)),
                     },
@@ -762,6 +762,8 @@ impl Parser {
     pub fn parse_literal_string(&mut self) -> Result<String, ParserError> {
         match self.next_token() {
             Some(Token::String(ref s)) => Ok(s.clone()),
+            Some(Token::SingleQuotedString(ref s)) => Ok(s.clone()),
+            Some(Token::DoubleQuotedString(ref s)) => Ok(s.clone()),
             other => parser_err!(format!("Expected literal string, found {:?}", other)),
         }
     }
